#ifndef SFDO_VERSION_H
#define SFDO_VERSION_H

#define SFDO_VERSION_STR "0.1.4"

#define SFDO_VERSION_MAJOR 0
#define SFDO_VERSION_MINOR 1
#define SFDO_VERSION_PATCH 4

#define SFDO_VERSION ((SFDO_VERSION_MAJOR << 16) | (SFDO_VERSION_MINOR << 8) | SFDO_VERSION_PATCH)

#endif
